
import CssModulesTransform from 'react-css-modules';
import { propTypes as tcombPropTypes } from 'tcomb-react';

import FlagIcon from './FlagIcon';
import styles from '../styles';
import { makeStyles, makeFlagIconOptions } from '../functions';
import { FlagIconPropsTypeTcomb } from '../types/tcomb';


var FlagIconFactory = function FlagIconFactory(React, options) {
  var computedOptions = makeFlagIconOptions(options);
  var useCssModules = computedOptions.useCssModules;

  var FlagIconComponent = FlagIcon(React, computedOptions);

  if (process.env.NODE_ENV !== 'production') {
    FlagIconComponent = Object.assign(FlagIconComponent, {
      propTypes: tcombPropTypes(FlagIconPropsTypeTcomb)
    });
  }

  if (useCssModules) {
    var computedStyles = makeStyles(styles, options);

    if (process.env.NODE_ENV !== 'production') {
      if (useCssModules) {
        var userSetUseCssModules = options ? options.useCssModules : false;

        if (!Object.prototype.hasOwnProperty.call(computedStyles, 'flag-icon')) {
          var readme = 'https://github.com/matteocng/react-flag-icon-css/blob/master/README.md';
          var readmeModules = 'https://github.com/gajus/react-css-modules#usage';

          console.error('Warning: Detected configuration mismatch/error: [react-flag-icon-css] FlagIconFactory tried to build FlagIcon with the option \'useCssModules\' set to true (' + (userSetUseCssModules ? 'by you' : 'default') + '), but it seems that your environment is not loading the stylesheets in the appropriate way. Two possibilities: \n\n 1. Your project is not using CSS Modules / you don\'t want to use them. Try building FlagIcon like this: \n\n\tFlagIconFactory(React, { useCssModules: false }) \n\n\tSee the README for more info: ' + readme + ' \n\n 2. You are using CSS Modules but your module bundler e.g Webpack is not correctly set up for CSS modules. If you are using Webpack, the key modules to set up are \'style-loader\', \'css-loader\' and \'extract-text-webpack-plugin\' (\'sass-loader\' also comes into play if you are using SASS). The link below may help you:\n\n\t' + readmeModules);
        }
      }
    }

    return CssModulesTransform(FlagIconComponent, computedStyles, { allowMultiple: true });
  }

  return FlagIconComponent;
};

export default FlagIconFactory;